package com.example.zobrazkovac;

import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

import com.androidquery.AQuery;

import android.content.Context;
import android.view.View;
import android.view.ViewGroup;
import android.widget.BaseAdapter;
import android.widget.GridView;
import android.widget.ImageView;

public class AsyncImageAdapter extends BaseAdapter {

	Context ctx;
	JSONArray photos;

	/**
	 * @param p
	 *            pole objektů obsahujících informace o jednotlivých fotkách
	 */
	public AsyncImageAdapter(Context c, JSONArray p) {
		ctx = c;
		photos = p;
	}

	public int getCount() {
		return photos.length();
	}

	public JSONObject getItem(int position) {
		// Prefix opt znamená, že neexistuje-li požadovaný prvek, místo výjimky
		// se vrátí null.
		return photos.optJSONObject(position);
	}

	public long getItemId(int position) {
		// Nepotřebujeme
		return 0;
	}

	public View getView(int position, View convertView, ViewGroup parent) {
		try {
			JSONObject photo = photos.getJSONObject(position);
			ImageView imageView;
			if (convertView == null) { // Nerecyklujeme, musíme nastavit některé
										// atributy
				imageView = new ImageView(ctx);
				imageView.setLayoutParams(new GridView.LayoutParams(150, 150));
				imageView.setScaleType(ImageView.ScaleType.CENTER_CROP);
				imageView.setPadding(8, 8, 8, 8);
			} else {
				imageView = (ImageView) convertView;
			}
			// Díky šikovnému AQuery (mimochodem konstruktor
			// new AQuery(View root);) do ImageView stáhneme obrázek jednoduše.
			// Z počátku to bude jen prázdné ImageView, obrázek se tam stáhne
			// asynchronně.
			new AQuery(imageView).image(getThumbUrl(photo));
			return imageView;
		} catch (JSONException e) {
			return null;
		}
	}

	// Vrátí url obrázku bez přípony.
	private static String getImgUrl(JSONObject photo) throws JSONException {
		return "http://farm" + String.valueOf(photo.getInt("farm"))
				+ ".staticflickr.com/" + photo.getString("server") + "/"
				+ photo.getString("id") + "_" + photo.getString("secret");
	}

	// K url obrázku získanému z getImgUrl připojí ještě _q, což znamená čtverec
	// 150x150px, a koncovku
	public static String getThumbUrl(JSONObject photo) {
		String url;
		try {
			url = getImgUrl(photo);
			return url + "_q.jpg";
		} catch (JSONException e) {
			return null;
		}
	}

	// K url obrázku získanému z getImgUrl připojí ještě _b, což znamená
	// maximální velikost, a koncovku
	public static String getLargeImgUrl(JSONObject photo) {
		String url;
		try {
			url = getImgUrl(photo);
			return url + "_b.jpg";
		} catch (JSONException e) {
			return null;
		}
	}

}
