package com.example.zobrazkovac;

import java.net.URI;
import java.net.URISyntaxException;

import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

import android.app.Activity;
import android.content.Intent;
import android.os.Bundle;
import android.view.View;
import android.widget.AdapterView;
import android.widget.Toast;

import com.androidquery.AQuery;
import com.androidquery.callback.AjaxStatus;

public class ShowPhotosActivity extends Activity {
	public static final String EXTRA_USER_ID = "userId";
	private static final String API_KEY = "d83b7ba2def7c2d762b86f9559d31fad";
	private static final String STATUS_OK = "ok";

	AQuery aq;
	AsyncImageAdapter adapter;

	@Override
	public void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.grid);

		aq = new AQuery(this);

		try {
			URI url = new URI("http", "api.flickr.com", "/services/rest",
					"method=flickr.people.getPublicPhotos&api_key=" + API_KEY
							+ "&user_id="
							+ getIntent().getStringExtra(EXTRA_USER_ID)
							+ "&format=json&nojsoncallback=1", null);

			// Zde si musím dát pozor na to, že nezachycené výjimky v
			// onPhotosFetched jsou odchytávány
			aq.progress(R.id.progressbar).ajax(url.toString(),
					JSONObject.class, this, "onPhotosFetched");
		} catch (URISyntaxException e) {
			// Tohle by se nikdy stát nemělo
			Toast.makeText(this, "Nepovedlo se vytvořit URI", Toast.LENGTH_LONG);
		}

		// Nastavení posluchače při kliknutí na jednotlivé thumbnaily. Opět si
		// musím dát pozor, že nezachycené výjimky jsou odchytávány.
		aq.id(R.id.grid).itemClicked(this, "onPhotoClick");
	}

	public void onPhotosFetched(String url, JSONObject json, AjaxStatus status) {
		if (json != null) {
			try {
				String stat = json.getString("stat");
				if (!stat.equals(STATUS_OK)) {
					// Chyba při volání API - špatný API klíč, neexistující
					// id, ...
					signalizeError();
					return;
				}
				// Vrácený JSON vypadá zhruba takto:
				// { "photos": { "photo": [{...}, ...], ... }}
				JSONObject photosObj = json.getJSONObject("photos");
				JSONArray photos = photosObj.getJSONArray("photo");

				adapter = new AsyncImageAdapter(this, photos);

				// Po úspěšném stažení seznamu obrázků nastavíme GridView
				// Adapter.
				aq.id(R.id.grid).adapter(adapter);
			} catch (JSONException e) {
				signalizeError();
			}
		} else {
			signalizeError();
		}
	}

	private void signalizeError() {
		Toast.makeText(this, "Chyba", Toast.LENGTH_LONG).show();
	}

	public void onPhotoClick(AdapterView<?> parent, View v, int position,
			long id) {
		Intent i = new Intent(this, SinglePhotoActivity.class);
		// Neřešíme NullPointerException, kdyby adapter.getItem(position)
		// vrátilo null
		i.putExtra(SinglePhotoActivity.PHOTO_URL,
				AsyncImageAdapter.getLargeImgUrl(adapter.getItem(position)));
		startActivity(i);
	}

}
