package com.example.zobrazkovac;

import java.net.URI;
import java.net.URISyntaxException;

import org.json.JSONException;
import org.json.JSONObject;

import android.app.Activity;
import android.content.Intent;
import android.os.Bundle;
import android.view.View;
import android.widget.Toast;

import com.androidquery.AQuery;
import com.androidquery.callback.AjaxCallback;
import com.androidquery.callback.AjaxStatus;
import com.androidquery.util.AQUtility;

public class ZobrazkovacActivity extends Activity {
	private static final String API_KEY = "d83b7ba2def7c2d762b86f9559d31fad";
	private static final String STATUS_OK = "ok";

	AQuery aq;

	@Override
	public void onCreate(Bundle savedInstanceState) {
		AQUtility.setDebug(true); // !! ODSTRANIT PŘED ZABALENÍM A PODEPSÁNÍM !!
		super.onCreate(savedInstanceState);
		setContentView(R.layout.main);

		aq = new AQuery(this);

		// Přidáme tlačítku OnClickListener
		aq.id(R.id.submit).clicked(new View.OnClickListener() {

			public void onClick(View v) {
				// Zjistíme obsah EditTextu
				String nick = aq.id(R.id.nick).getText().toString();
				try {
					// Url už musí být zakódované a v nicku mohou být nepovolené
					// znaky, proto musíme url vytvořít takhle
					URI url = new URI("http", "api.flickr.com",
							"/services/rest",
							"method=flickr.people.findByUsername&api_key="
									+ API_KEY
									+ "&format=json&nojsoncallback=1&username="
									+ nick, null);

					// Místo ajax(url.toString(), this, "onUserFetched") jsem
					// použil toto řešení, neboť v případě výjimky vyskočí
					// oznámení a zabije to aplikaci. Pro mě je to chtěné
					// chování.
					// Pozor ovšem na to, že AQuery stejně odchytává chyby ve
					// své ajaxové funkci (například
					// org.apache.http.conn.ConnectTimeoutException)
					aq.progress(R.id.progressbar).ajax(url.toString(),
							JSONObject.class, new AjaxCallback<JSONObject>() {

								@Override
								public void callback(String url,
										JSONObject json, AjaxStatus status) {
									onUserFetched(url, json, status);
								}
							});
				} catch (URISyntaxException e) {
					Toast.makeText(ZobrazkovacActivity.this,
							"Nepovedlo se vytvořit URI", Toast.LENGTH_LONG);
				}
			}
		});
	}

	public void onUserFetched(String url, JSONObject json, AjaxStatus status) {
		if (json != null) {
			try {
				// Pro dokumentaci JSON tříd viz
				// http://www.json.org/javadoc/org/json/JSONObject.html
				String stat = json.getString("stat");
				if (!stat.equals(STATUS_OK)) {
					// Chyba při volání API - špatný API klíč, neexistující
					// uživatel, ...
					signalizeError();
					return;
				}
				JSONObject user = json.getJSONObject("user");
				String id = user.getString("nsid");

				Intent i = new Intent(this, ShowPhotosActivity.class);
				i.putExtra(ShowPhotosActivity.EXTRA_USER_ID, id);
				startActivity(i);

			} catch (JSONException e) {
				signalizeError();
			}
		} else {
			signalizeError();
		}
	}

	// V reálné aplikaci by to samozřejmě bylo trochu popisnější
	private void signalizeError() {
		Toast.makeText(this, "Chyba", Toast.LENGTH_LONG).show();
	}
}